@@ -1288,22 +1288,22 @@ static void account_list_view_add(PrefsAccount *ac_prefs)
 #ifdef USE_GNUTLS
 	protocol = ac_prefs->protocol == A_POP3 ?
 		  (ac_prefs->ssl_pop == SSL_TUNNEL ?
-		   "POP3 (SSL)" :
+		   "POP (SSL/TLS)" :
 		   ac_prefs->ssl_pop == SSL_STARTTLS ?
-		   "POP3 (TLS)" : "POP3") :
+		   "POP (STARTTLS)" : "POP") :
 		   ac_prefs->protocol == A_IMAP4 ?
 		  (ac_prefs->ssl_imap == SSL_TUNNEL ?
-		   "IMAP4 (SSL)" :
+		   "IMAP (SSL/TLS)" :
 		   ac_prefs->ssl_imap == SSL_STARTTLS ?
-		   "IMAP4 (TLS)" : "IMAP4") :
+		   "IMAP (STARTTLS)" : "IMAP") :
 		   ac_prefs->protocol == A_NNTP ?
 		  (ac_prefs->ssl_nntp == SSL_TUNNEL ?
-		   "NNTP (SSL)" : "NNTP") :
+		   "NNTP (SSL/TLS)" : "NNTP") :
 		   ac_prefs->protocol == A_LOCAL ? "Local" :
 		   ac_prefs->protocol == A_NONE ?  "SMTP" : "-";
 #else
-	protocol = ac_prefs->protocol == A_POP3  ? "POP3" :
-		   ac_prefs->protocol == A_IMAP4 ? "IMAP4" :
+	protocol = ac_prefs->protocol == A_POP3  ? "POP" :
+		   ac_prefs->protocol == A_IMAP4 ? "IMAP" :
 		   ac_prefs->protocol == A_LOCAL ? "Local" :
 		   ac_prefs->protocol == A_NNTP  ? "NNTP" :
 		   ac_prefs->protocol == A_NONE ?  "SMTP" : "-";
