@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2013 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 #ifndef __DEFS_H__
@@ -39,6 +38,7 @@
 #define QUEUE_DIR		"queue"
 #define DRAFT_DIR		"draft"
 #define TRASH_DIR		"trash"
+#define TAGS_DIR		"tagsdb"
 #define RC_DIR			CFG_RC_DIR
 #define OLD_GTK2_RC_DIR		".sylpheed-claws"
 #define OLDER_GTK2_RC_DIR	".sylpheed-gtk2"
@@ -46,7 +46,6 @@
 #define SYLPHEED_RC_DIR		".sylpheed-2.0"
 #define NEWS_CACHE_DIR		"newscache"
 #define IMAP_CACHE_DIR		"imapcache"
-#define MBOX_CACHE_DIR		"mboxcache"
 #define HEADER_CACHE_DIR        "headercache" 
 #define MIME_TMP_DIR		"mimetmp"
 #define COMMON_RC		"clawsrc"
@@ -61,6 +60,7 @@
 #define MENU_RC			"menurc"
 #define RENDERER_RC		"rendererrc"
 #define TAGS_RC			"tagsrc"
+#define PASSWORD_STORE_RC			"passwordstorerc"
 #define QUICKSEARCH_HISTORY	"quicksearch_history"
 #define SUMMARY_SEARCH_FROM_HISTORY	"summarysearch_from_history"
 #define SUMMARY_SEARCH_TO_HISTORY	"summarysearch_to_history"
@@ -90,6 +90,7 @@
 #define USERS_ML_URI		"http://lists.claws-mail.org/cgi-bin/mailman/listinfo/users"
 #define GPL_URI			"http://www.gnu.org/licenses/gpl.html"
 #define DONATE_URI		"http://www.claws-mail.org/sponsors.php"
+#define CONFIG_VERSIONS_URI	"http://www.claws-mail.org/cvc.php"
 #define RELEASE_NOTES_FILE	"RELEASE_NOTES"
 #define THEMEINFO_FILE		".claws_themeinfo"
 #define FOLDER_LIST		"folderlist.xml"
