@@ -226,7 +226,7 @@ gboolean mh_scan_required(Folder *folder, FolderItem *item)
 	if ((s.st_mtime > item->mtime) &&
 		(s.st_mtime - 3600 != item->mtime)) {
 		debug_print("MH scan required, folder updated: %s (%ld > %ld)\n",
-			    path?path:"(null)",
+			    path,
 			    (long int) s.st_mtime,
 			    (long int) item->mtime);
 		g_free(path);
@@ -234,7 +234,7 @@ gboolean mh_scan_required(Folder *folder, FolderItem *item)
 	}
 
 	debug_print("MH scan not required: %s (%ld <= %ld)\n",
-		    path?path:"(null)",
+		    path,
 		    (long int) s.st_mtime,
 		    (long int) item->mtime);
 	g_free(path);
@@ -792,7 +792,7 @@ static gint mh_create_tree(Folder *folder)
 #ifdef G_OS_UNIX
 	if (*rootpath == '/') {
 #elif defined G_OS_WIN32
-	if (g_ascii_isalpha(*rootpath) && !strncmp(rootpath + 1, "\:", 2)) {
+	if (g_ascii_isalpha(*rootpath) && !strncmp(rootpath + 1, ":\\", 2)) {
 #endif
 		/* Folder path is absolute. */
 		rootpath = g_strdup(rootpath);
