@@ -530,7 +530,7 @@ static void mimeview_free_mimeinfo(MimeView *mimeview)
 		mimeview->check_data->free_after_use = TRUE;
 #endif
 	if (mimeview->mimeinfo != NULL && !defer) {
-		procmime_mimeinfo_free_all(mimeview->mimeinfo);
+		procmime_mimeinfo_free_all(&mimeview->mimeinfo);
 		mimeview->mimeinfo = NULL;
 	} else if (defer) {
 #ifdef USE_PTHREAD
@@ -1112,7 +1112,7 @@ static void mimeview_check_data_reset(MimeView *mimeview)
 
 	if (must_free) {
 		debug_print("freeing deferred mimeinfo\n");
-		procmime_mimeinfo_free_all(mimeview->check_data->siginfo);
+		procmime_mimeinfo_free_all(&mimeview->check_data->siginfo);
 	}
 
 	g_free(mimeview->check_data);
@@ -2213,7 +2213,7 @@ static void mimeview_view_file(const gchar *filename, MimeInfo *partinfo,
 			g_warning("MIME viewer command-line is invalid: '%s'", cmd);
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
  		}
-		if (execute_command_line(buf, TRUE) != 0) {
+		if (execute_command_line(buf, TRUE, NULL) != 0) {
 			if (!prefs_common.save_parts_readwrite)
 				g_chmod(filename, S_IRUSR|S_IWUSR);
 			mimeview_open_part_with(mimeview, partinfo, FALSE);
@@ -2504,29 +2504,29 @@ static void icon_list_append_icon (MimeView *mimeview, MimeInfo *mimeinfo)
 		case SIGNATURE_UNCHECKED:
 		case SIGNATURE_CHECK_FAILED:
 		case SIGNATURE_CHECK_TIMEOUT:
-			pixmap = stock_pixmap_widget_with_overlay(mimeview->mainwin->window, stockp,
+			pixmap = stock_pixmap_widget_with_overlay(stockp,
 			    STOCK_PIXMAP_PRIVACY_EMBLEM_SIGNED, OVERLAY_BOTTOM_RIGHT, 6, 3);
 			break;
 		case SIGNATURE_OK:
-			pixmap = stock_pixmap_widget_with_overlay(mimeview->mainwin->window, stockp,
+			pixmap = stock_pixmap_widget_with_overlay(stockp,
 			    STOCK_PIXMAP_PRIVACY_EMBLEM_PASSED, OVERLAY_BOTTOM_RIGHT, 6, 3);
 			break;
 		case SIGNATURE_WARN:
 		case SIGNATURE_KEY_EXPIRED:
-			pixmap = stock_pixmap_widget_with_overlay(mimeview->mainwin->window, stockp,
+			pixmap = stock_pixmap_widget_with_overlay(stockp,
 			    STOCK_PIXMAP_PRIVACY_EMBLEM_WARN, OVERLAY_BOTTOM_RIGHT, 6, 3);
 			break;
 		case SIGNATURE_INVALID:
-			pixmap = stock_pixmap_widget_with_overlay(mimeview->mainwin->window, stockp,
+			pixmap = stock_pixmap_widget_with_overlay(stockp,
 			    STOCK_PIXMAP_PRIVACY_EMBLEM_FAILED, OVERLAY_BOTTOM_RIGHT, 6, 3);
 			break;
 		}
 		sigshort = privacy_mimeinfo_sig_info_short(siginfo);
 	} else if (encrypted != NULL) {
-			pixmap = stock_pixmap_widget_with_overlay(mimeview->mainwin->window, stockp,
+			pixmap = stock_pixmap_widget_with_overlay(stockp,
 			    STOCK_PIXMAP_PRIVACY_EMBLEM_ENCRYPTED, OVERLAY_BOTTOM_RIGHT, 6, 3);		
 	} else {
-		pixmap = stock_pixmap_widget_with_overlay(mimeview->mainwin->window, stockp, 0,
+		pixmap = stock_pixmap_widget_with_overlay(stockp, 0,
 							  OVERLAY_NONE, 6, 3);
 	}
 	gtk_container_add(GTK_CONTAINER(button), pixmap);
