@@ -387,8 +387,8 @@ static Session *news_session_new_for_folder(Folder *folder)
 	if (ac->ssl_nntp != SSL_NONE) {
 		if (alertpanel_full(_("Insecure connection"),
 			_("This connection is configured to be secured "
-			  "using SSL, but SSL is not available in this "
-			  "build of Claws Mail. \n\n"
+			  "using SSL/TLS, but SSL/TLS is not available "
+			  "in this build of Claws Mail. \n\n"
 			  "Do you want to continue connecting to this "
 			  "server? The communication would not be "
 			  "secure."),
@@ -945,7 +945,10 @@ gint news_cancel_article(Folder * folder, MsgInfo * msginfo)
 		g_warning("can't change file mode");
 	}
 	
-	get_rfc822_date(buf, sizeof(buf));
+	if (prefs_common.hide_timezone)
+		get_rfc822_date_hide_tz(buf, sizeof(buf));
+	else
+		get_rfc822_date(buf, sizeof(buf));
 	if (fprintf(tmpfp, "From: %s\r\n"
 		       "Newsgroups: %s\r\n"
 		       "Subject: cmsg cancel <%s>\r\n"
