@@ -328,7 +328,7 @@ static int partial_uidl_mark_mail(MsgInfo *msginfo, int download)
 	err = 0;
 bail:
 	g_free(filename);
-	procmsg_msginfo_free(tinfo);
+	procmsg_msginfo_free(&tinfo);
 	
 	return err;
 }
