@@ -51,6 +51,11 @@
 #include "gtk/manage_window.h"
 #include "common/utils.h"
 #include "gtk/gtkutils.h"
+#include "inc.h"
+
+static void notification_trayicon_account_list_reset(const gchar *,
+														gpointer,
+														gboolean);
 
 static GdkPixbuf* notification_trayicon_create(void);
 
@@ -60,6 +65,7 @@ static gboolean notification_trayicon_on_size_changed(GtkStatusIcon*,
 						      gint, gpointer);
 
 static void trayicon_get_all_cb(GtkAction*, gpointer);
+static void trayicon_get_from_account_cb(GtkAction*, gpointer);
 static void trayicon_compose_cb(GtkAction*, gpointer);
 static void trayicon_compose_acc_cb(GtkMenuItem*, gpointer);
 static void trayicon_addressbook_cb(GtkAction*, gpointer);
@@ -108,10 +114,12 @@ G_LOCK_DEFINE_STATIC(trayicon_popup);
 static GtkStatusIcon *trayicon;
 static gboolean updating_menu = FALSE;
 static GtkWidget *traymenu_popup;
+static GtkWidget *focused_widget = NULL;
 
 static GtkActionEntry trayicon_popup_menu_entries[] = {
 	{"SysTrayiconPopup", NULL, "SysTrayiconPopup" },
 	{"SysTrayiconPopup/GetMail", NULL, N_("_Get Mail"), NULL, NULL, G_CALLBACK(trayicon_get_all_cb) },
+	{"SysTrayiconPopup/GetMailAcc", NULL, N_("_Get Mail from account"), NULL, NULL, NULL },
 	{"SysTrayiconPopup/---", NULL, "---" },
 	{"SysTrayiconPopup/Email", NULL, N_("_Email"), NULL, NULL, G_CALLBACK(trayicon_compose_cb) },
 	{"SysTrayiconPopup/EmailAcc", NULL, N_("E_mail from account"), NULL, NULL, NULL },
@@ -310,8 +318,10 @@ gboolean notification_trayicon_main_window_close(gpointer source, gpointer data)
       MainWindow *mainwin = mainwindow_get_mainwindow();
 
       *close_allowed = FALSE;
-      if(mainwin && gtk_widget_get_visible(GTK_WIDGET(mainwin->window)))
+      if(mainwin && gtk_widget_get_visible(GTK_WIDGET(mainwin->window))) {
+	focused_widget = gtk_window_get_focus(GTK_WINDOW(mainwin->window));
 	main_window_hide(mainwin);
+      }
     }
   }
   return FALSE;
@@ -333,40 +343,53 @@ gboolean notification_trayicon_main_window_got_iconified(gpointer source,
   return FALSE;
 }
 
-gboolean notification_trayicon_account_list_changed(gpointer source,
-						    gpointer data)
+static void notification_trayicon_account_list_reset(const gchar *menuname,
+													gpointer callback,
+													gboolean receive)
 {
-  GList *cur_ac;
+    GList *cur_ac;
 	GtkWidget *menu, *submenu;
-  GtkWidget *menuitem;
-  PrefsAccount *ac_prefs;
+    GtkWidget *menuitem;
+    PrefsAccount *ac_prefs;
 
-  GList *account_list = account_get_list();
+    GList *account_list = account_get_list();
 
-  if(!notify_config.trayicon_enabled)
-    return FALSE;
-
-	menu = gtk_ui_manager_get_widget(gtkut_ui_manager(), "/Menus/SysTrayiconPopup/EmailAcc");
+	menu = gtk_ui_manager_get_widget(gtkut_ui_manager(), menuname);
 	gtk_widget_show(menu);
 
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu), NULL);
 	submenu = gtk_menu_new();
 
-  for(cur_ac = account_list; cur_ac != NULL; cur_ac = cur_ac->next) {
-    ac_prefs = (PrefsAccount *)cur_ac->data;
+	for(cur_ac = account_list; cur_ac != NULL; cur_ac = cur_ac->next) {
+		ac_prefs = (PrefsAccount *)cur_ac->data;
 
-    menuitem = gtk_menu_item_new_with_label
-      (ac_prefs->account_name ? ac_prefs->account_name
-       : _("Untitled"));
-    gtk_widget_show(menuitem);
+		/* accounts list for receiving: skip SMTP-only accounts */
+		if (receive && ac_prefs->protocol == A_NONE)
+			continue;
+
+		menuitem = gtk_menu_item_new_with_label
+						(ac_prefs->account_name ? ac_prefs->account_name
+						: _("Untitled"));
+		gtk_widget_show(menuitem);
 		gtk_menu_shell_append(GTK_MENU_SHELL(submenu), menuitem);
-    g_signal_connect(G_OBJECT(menuitem), "activate",
-		     G_CALLBACK(trayicon_compose_acc_cb),
-		     ac_prefs);
-  }
+		g_signal_connect(G_OBJECT(menuitem), "activate",
+				G_CALLBACK(callback),
+				ac_prefs);
+	}
 	gtk_widget_show(submenu);
 	gtk_menu_item_set_submenu(GTK_MENU_ITEM(menu), submenu);
-  return FALSE;
+}
+
+gboolean notification_trayicon_account_list_changed(gpointer source,
+						    gpointer data)
+{
+	if (notify_config.trayicon_enabled) {
+	  	notification_trayicon_account_list_reset("/Menus/SysTrayiconPopup/GetMailAcc",
+												(gpointer)trayicon_get_from_account_cb, TRUE);
+		notification_trayicon_account_list_reset("/Menus/SysTrayiconPopup/EmailAcc",
+												(gpointer)trayicon_compose_acc_cb, FALSE);
+	}
+	return FALSE;
 }
 
 static GdkPixbuf* notification_trayicon_create(void)
@@ -395,6 +418,7 @@ static GdkPixbuf* notification_trayicon_create(void)
 
 	MENUITEM_ADDUI("/Menus", "SysTrayiconPopup", "SysTrayiconPopup", GTK_UI_MANAGER_MENU)
 	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "GetMail", "SysTrayiconPopup/GetMail", GTK_UI_MANAGER_MENUITEM)
+	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "GetMailAcc", "SysTrayiconPopup/GetMailAcc", GTK_UI_MANAGER_MENU)
 	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Separator1", "SysTrayiconPopup/---", GTK_UI_MANAGER_SEPARATOR)
 	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "Email", "SysTrayiconPopup/Email", GTK_UI_MANAGER_MENUITEM)
 	MENUITEM_ADDUI("/Menus/SysTrayiconPopup", "EmailAcc", "SysTrayiconPopup/EmailAcc", GTK_UI_MANAGER_MENU)
@@ -417,7 +441,15 @@ static GdkPixbuf* notification_trayicon_create(void)
 
 void notification_trayicon_on_activate(GtkStatusIcon *status_icon, gpointer user_data)
 {
+  MainWindow *mainwin = mainwindow_get_mainwindow();
+
+  if(mainwin && gtk_widget_get_visible(GTK_WIDGET(mainwin->window)) == TRUE)
+    focused_widget = gtk_window_get_focus(GTK_WINDOW(mainwin->window));
+
   notification_toggle_hide_show_window();
+
+  if(mainwin && gtk_widget_get_visible(GTK_WIDGET(mainwin->window)) == TRUE)
+    gtk_window_set_focus(GTK_WINDOW(mainwin->window), focused_widget);
 }
 
 static void notification_trayicon_on_popup_menu(GtkStatusIcon *status_icon,
@@ -459,6 +491,13 @@ static void trayicon_get_all_cb(GtkAction *action, gpointer data)
   inc_all_account_mail_cb(mainwin, 0, NULL);
 }
 
+static void trayicon_get_from_account_cb(GtkAction *action, gpointer data)
+{
+  MainWindow *mainwin = mainwindow_get_mainwindow();
+  PrefsAccount *account = (PrefsAccount *)data;
+  inc_account_mail(mainwin, account);
+}
+
 static void trayicon_compose_cb(GtkAction *action, gpointer data)
 {
   MainWindow *mainwin = mainwindow_get_mainwindow();
