@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2015 the Claws Mail team
+ * Copyright (C) 1999-2016 the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,6 +35,9 @@
 #include <sys/types.h>
 #ifndef G_OS_WIN32
 #  include <sys/wait.h>
+#else
+#  include <pthread.h>
+#  include <windows.h>
 #endif
 #if (defined(__DragonFly__) || defined(SOLARIS) || defined (__NetBSD__) || defined (__FreeBSD__) || defined (__OpenBSD__))
 #  include <sys/signal.h>
@@ -55,6 +58,7 @@
 #include "prefs_gpg.h"
 #include "account.h"
 #include "select-keys.h"
+#include "claws.h"
 
 static void sgpgme_disable_all(void)
 {
@@ -168,6 +172,40 @@ static const gchar *get_owner_trust_str(unsigned long owner_trust)
 	}
 }
 
+gchar *get_gpg_executable_name()
+{
+	gpgme_engine_info_t e;
+
+	if (!gpgme_get_engine_info(&e)) {
+		while (e != NULL) {
+			if (e->protocol == GPGME_PROTOCOL_OpenPGP
+					&& e->file_name != NULL) {
+				debug_print("Found gpg executable: '%s'\n", e->file_name);
+				return e->file_name;
+			}
+		}
+	}
+
+	return NULL;
+}
+
+static gchar *get_gpg_version_string()
+{
+	gpgme_engine_info_t e;
+
+	if (!gpgme_get_engine_info(&e)) {
+		while (e != NULL) {
+			if (e->protocol == GPGME_PROTOCOL_OpenPGP
+					&& e->version != NULL) {
+				debug_print("Got OpenPGP version: '%s'\n", e->version);
+				return e->version;
+			}
+		}
+	}
+
+	return NULL;
+}
+
 static gchar *extract_name(const char *uid)
 {
 	if (uid == NULL)
@@ -583,17 +621,17 @@ gboolean sgpgme_setup_signers(gpgme_ctx_t ctx, PrefsAccount *account,
 			}
 
 			if (key->expired) {
-				debug_print("skipping a key, expired");
+				debug_print("skipping a key, expired\n");
 				gpgme_key_release(key);
 				continue;
 			}
 			if (key->revoked) {
-				debug_print("skipping a key, revoked");
+				debug_print("skipping a key, revoked\n");
 				gpgme_key_release(key);
 				continue;
 			}
 			if (key->disabled) {
-				debug_print("skipping a key, disabled");
+				debug_print("skipping a key, disabled\n");
 				gpgme_key_release(key);
 				continue;
 			}
@@ -643,12 +681,16 @@ void sgpgme_init()
 {
 	gchar *ctype_locale = NULL, *messages_locale = NULL;
 	gchar *ctype_utf8_locale = NULL, *messages_utf8_locale = NULL;
+	gpgme_error_t err = 0;
 
 	gpgme_engine_info_t engineInfo;
 
-	if (strcmp(prefs_gpg_get_config()->gpg_path, "") != 0 &&
-	    access(prefs_gpg_get_config()->gpg_path, X_OK) != -1)
-		gpgme_set_engine_info(GPGME_PROTOCOL_OpenPGP,prefs_gpg_get_config()->gpg_path, NULL);
+	if (strcmp(prefs_gpg_get_config()->gpg_path, "") != 0
+	    && access(prefs_gpg_get_config()->gpg_path, X_OK) != -1) {
+		err = gpgme_set_engine_info(GPGME_PROTOCOL_OpenPGP, prefs_gpg_get_config()->gpg_path, NULL);
+		if (err != GPG_ERR_NO_ERROR)
+			g_warning("failed to set crypto engine configuration: %s", gpgme_strerror(err));
+	}
 
 	if (gpgme_check_version("1.0.0")) {
 #ifdef LC_CTYPE
@@ -760,6 +802,48 @@ void sgpgme_done()
         gpgmegtk_free_passphrase();
 }
 
+#ifdef G_OS_WIN32
+struct _ExportCtx {
+	gboolean done;
+	gchar *cmd;
+	DWORD exitcode;
+};
+
+static void *_export_threaded(void *arg)
+{
+	struct _ExportCtx *ctx = (struct _ExportCtx *)arg;
+	gboolean result;
+
+	PROCESS_INFORMATION pi = {0};
+	STARTUPINFO si = {0};
+
+	result = CreateProcess(NULL, ctx->cmd, NULL, NULL, FALSE,
+			NORMAL_PRIORITY_CLASS | CREATE_NO_WINDOW,
+			NULL, NULL, &si, &pi);
+
+	if (!result) {
+		debug_print("Couldn't execute '%s'\n", ctx->cmd);
+	} else {
+		WaitForSingleObject(pi.hProcess, 10000);
+		result = GetExitCodeProcess(pi.hProcess, &ctx->exitcode);
+		if (ctx->exitcode == STILL_ACTIVE) {
+			debug_print("Process still running, terminating it.\n");
+			TerminateProcess(pi.hProcess, 255);
+		}
+
+		CloseHandle(pi.hProcess);
+		CloseHandle(pi.hThread);
+
+		if (!result) {
+			debug_print("Process executed, but we couldn't get its exit code (huh?)\n");
+		}
+	}
+
+	ctx->done = TRUE;
+	return NULL;
+}
+#endif
+
 void sgpgme_create_secret_key(PrefsAccount *account, gboolean ask_create)
 {
 	AlertValue val = G_ALERTDEFAULT;
@@ -768,11 +852,12 @@ void sgpgme_create_secret_key(PrefsAccount *account, gboolean ask_create)
 	gchar *email = NULL;
 	gchar *passphrase = NULL, *passphrase_second = NULL;
 	gint prev_bad = 0;
-	gchar *tmp = NULL;
+	gchar *tmp = NULL, *gpgver;
 	gpgme_error_t err = 0;
 	gpgme_ctx_t ctx;
 	GtkWidget *window = NULL;
 	gpgme_genkey_result_t key;
+	gboolean exported = FALSE;
 
 	if (account == NULL)
 		account = account_get_default();
@@ -790,8 +875,6 @@ void sgpgme_create_secret_key(PrefsAccount *account, gboolean ask_create)
 				  "Do you want to create a new key pair now?"),
 				  GTK_STOCK_NO, "+" GTK_STOCK_YES, NULL);
 		if (val == G_ALERTDEFAULT) {
-			prefs_gpg_get_config()->gpg_ask_create_key = FALSE;
-			prefs_gpg_save_config();
 			return;
 		}
 	}
@@ -803,27 +886,40 @@ void sgpgme_create_secret_key(PrefsAccount *account, gboolean ask_create)
 	}
 	email = g_strdup(account->address);
 	tmp = g_strdup_printf("%s <%s>", account->name?account->name:account->address, account->address);
+	gpgver = get_gpg_version_string();
+	if (gpgver == NULL || !strncmp(gpgver, "1.", 2)) {
+		debug_print("Using gpg 1.x, using builtin passphrase dialog.\n");
 again:
-	passphrase = passphrase_mbox(tmp, NULL, prev_bad, 1);
-	if (passphrase == NULL) {
-		g_free(tmp);
-		g_free(email);
-		g_free(name);		
-		return;
-	}
-	passphrase_second = passphrase_mbox(tmp, NULL, 0, 2);
-	if (passphrase_second == NULL) {
-		g_free(tmp);
-		g_free(email);
-		g_free(passphrase);		
-		g_free(name);		
-		return;
-	}
-	if (strcmp(passphrase, passphrase_second)) {
-		g_free(passphrase);
-		g_free(passphrase_second);
-		prev_bad = 1;
-		goto again;
+		passphrase = passphrase_mbox(tmp, NULL, prev_bad, 1);
+		if (passphrase == NULL) {
+			g_free(tmp);
+			g_free(email);
+			g_free(name);
+			return;
+		}
+		passphrase_second = passphrase_mbox(tmp, NULL, 0, 2);
+		if (passphrase_second == NULL) {
+			g_free(tmp);
+			g_free(email);
+			if (passphrase != NULL) {
+				memset(passphrase, 0, strlen(passphrase));
+				g_free(passphrase);
+			}
+			g_free(name);
+			return;
+		}
+		if (strcmp(passphrase, passphrase_second)) {
+			if (passphrase != NULL) {
+				memset(passphrase, 0, strlen(passphrase));
+				g_free(passphrase);
+			}
+			if (passphrase_second != NULL) {
+				memset(passphrase_second, 0, strlen(passphrase_second));
+				g_free(passphrase_second);
+			}
+			prev_bad = 1;
+			goto again;
+		}
 	}
 	
 	key_parms = g_strdup_printf("<GnupgKeyParms format=\"internal\">\n"
@@ -837,26 +933,37 @@ again:
 					"%s%s%s"
 					"</GnupgKeyParms>\n",
 					name, email, 
-					strlen(passphrase)?"Passphrase: ":"",
-					passphrase,
-					strlen(passphrase)?"\n":"");
+					passphrase?"Passphrase: ":"",
+					passphrase?passphrase:"",
+					passphrase?"\n":"");
 #ifndef G_PLATFORM_WIN32
-	if (mlock(passphrase, strlen(passphrase)) == -1)
+	if (passphrase &&
+			mlock(passphrase, strlen(passphrase)) == -1)
 		debug_print("couldn't lock passphrase\n");
-	if (mlock(passphrase_second, strlen(passphrase_second)) == -1)
+	if (passphrase_second &&
+			mlock(passphrase_second, strlen(passphrase_second)) == -1)
 		debug_print("couldn't lock passphrase2\n");
 #endif
 	g_free(tmp);
 	g_free(email);
 	g_free(name);
-	g_free(passphrase_second);
-	g_free(passphrase);
+	if (passphrase_second != NULL) {
+		memset(passphrase_second, 0, strlen(passphrase_second));
+		g_free(passphrase_second);
+	}
+	if (passphrase != NULL) {
+		memset(passphrase, 0, strlen(passphrase));
+		g_free(passphrase);
+	}
 	
 	err = gpgme_new (&ctx);
 	if (err) {
 		alertpanel_error(_("Couldn't generate a new key pair: %s"),
 				 gpgme_strerror(err));
-		g_free(key_parms);
+		if (key_parms != NULL) {
+			memset(key_parms, 0, strlen(key_parms));
+			g_free(key_parms);
+		}
 		return;
 	}
 	
@@ -865,7 +972,10 @@ again:
 			      "around to help generate entropy..."));
 
 	err = gpgme_op_genkey(ctx, key_parms, NULL, NULL);
-	g_free(key_parms);
+	if (key_parms != NULL) {
+		memset(key_parms, 0, strlen(key_parms));
+		g_free(key_parms);
+	}
 
 	label_window_destroy(window);
 
@@ -888,8 +998,12 @@ again:
 				  GTK_STOCK_NO, "+" GTK_STOCK_YES, NULL);
 		g_free(buf);
 		if (val == G_ALERTALTERNATE) {
+			gchar *gpgbin = get_gpg_executable_name();
+			gchar *cmd = g_strdup_printf("\"%s\" --batch --no-tty --send-keys %s",
+				(gpgbin ? gpgbin : "gpg"), key->fpr);
+			debug_print("Executing command: %s\n", cmd);
+
 #ifndef G_OS_WIN32
-			gchar *cmd = g_strdup_printf("gpg --no-tty --send-keys %s", key->fpr);
 			int res = 0;
 			pid_t pid = 0;
 			pid = fork();
@@ -922,19 +1036,46 @@ again:
 					}
 				} while(1);
 			}
-			if (res == 0) {
+
+			if (res == 0)
+				exported = TRUE;
+#else
+			/* We need to call gpg in a separate thread, so that waiting for
+			 * it to finish does not block the UI. */
+			pthread_t pt;
+			struct _ExportCtx *ectx = malloc(sizeof(struct _ExportCtx));
+
+			ectx->done = FALSE;
+			ectx->exitcode = STILL_ACTIVE;
+			ectx->cmd = cmd;
+
+			if (pthread_create(&pt, PTHREAD_CREATE_JOINABLE,
+						_export_threaded, (void *)ectx) != 0) {
+				debug_print("Couldn't create thread, continuing unthreaded.\n");
+				_export_threaded(ctx);
+			} else {
+				debug_print("Thread created, waiting for it to finish...\n");
+				while (!ectx->done)
+					claws_do_idle();
+			}
+
+			debug_print("Thread finished.\n");
+			pthread_join(pt, NULL);
+
+			if (ectx->exitcode == 0)
+				exported = TRUE;
+
+			g_free(ectx);
+#endif
+			g_free(cmd);
+
+			if (exported) {
 				alertpanel_notice(_("Key exported."));
 			} else {
 				alertpanel_error(_("Couldn't export key."));
 			}
-			g_free(cmd);
-#else
-			alertpanel_error(_("Key export isn't implemented in Windows."));
-#endif
 		}
 	}
-	prefs_gpg_get_config()->gpg_ask_create_key = FALSE;
-	prefs_gpg_save_config();
 	gpgme_release(ctx);
 }
 
@@ -972,10 +1113,10 @@ void sgpgme_check_create_key(void)
 	if (prefs_gpg_get_config()->gpg_ask_create_key &&
 	    !sgpgme_has_secret_key()) {
 		sgpgme_create_secret_key(NULL, TRUE);
-	} else {
-		prefs_gpg_get_config()->gpg_ask_create_key = FALSE;
-		prefs_gpg_save_config();
-	}	
+	}
+
+	prefs_gpg_get_config()->gpg_ask_create_key = FALSE;
+	prefs_gpg_save_config();
 }
 
 void *sgpgme_data_release_and_get_mem(gpgme_data_t data, size_t *len)
