@@ -135,8 +135,7 @@ void rssyl_remove_folder_cb(GtkAction *action,
 			     gpointer data)
 {
 	FolderView *folderview = (FolderView*)data;
-	GtkCMCTree *ctree = GTK_CMCTREE(folderview->ctree);
-	FolderItem *item;
+	FolderItem *item, *opened;
 	gchar *message, *name;
 	AlertValue avalue;
 	gchar *old_id;
@@ -145,6 +144,7 @@ void rssyl_remove_folder_cb(GtkAction *action,
 	g_return_if_fail(item != NULL);
 	g_return_if_fail(item->path != NULL);
 	g_return_if_fail(item->folder != NULL);
+	opened = folderview_get_opened_item(folderview);
 
 	name = trim_string(item->name, 32);
 	AUTORELEASE_STR(name, {g_free(name); return;});
@@ -160,12 +160,10 @@ void rssyl_remove_folder_cb(GtkAction *action,
 
 	old_id = folder_item_get_identifier(item);
 
-	if (folderview->opened == folderview->selected ||
-	    gtk_cmctree_is_ancestor(ctree,
-				  folderview->selected,
-				  folderview->opened)) {
+	if (item == opened ||
+			folder_is_child_of(item, opened)) {
 		summary_clear_all(folderview->summaryview);
-		folderview->opened = NULL;
+		folderview_close_opened(folderview, TRUE);
 	}
 
 	if (item->folder->klass->remove_folder(item->folder, item) < 0) {
@@ -362,10 +360,7 @@ void rssyl_import_feed_list_cb(GtkAction *action, gpointer data)
 
 	ctx = malloc( sizeof(OPMLImportCtx) );
 	ctx->failures = 0;
-	/* This needs to be +2, since we will be comparing it to depth of
-	 * <outline> tag in OPML's XML structure. Topmost outlines are under
-	 * <opml> and <body>, hence 2. */
-	ctx->depth = rssyl_folder_depth(item) + 2;
+	ctx->depth = rssyl_folder_depth(item) + 1;
 	ctx->current = NULL;
 	ctx->current = g_slist_append(ctx->current, item);
 
