@@ -150,7 +150,7 @@ static void create_meeting_from_message_cb_ui(GtkAction *action, gpointer data)
 		}
 		
 		if (fp) {
-			gchar uid[256];
+			gchar *uid;
 			time_t t = time(NULL);
 			time_t t2 = t+3600;
 			gchar *org = NULL;
@@ -179,22 +179,13 @@ static void create_meeting_from_message_cb_ui(GtkAction *action, gpointer data)
 
 			org = g_strdup(account->address);
 
-			if (account->set_domain && account->domain) {
-				g_snprintf(uid, sizeof(uid), "%s", account->domain); 
-			} else if (!strncmp(get_domain_name(), "localhost", strlen("localhost"))) {
-				g_snprintf(uid, sizeof(uid), "%s", 
-					strchr(account->address, '@') ?
-					strchr(account->address, '@')+1 :
-					account->address);
-			} else {
-				g_snprintf(uid, sizeof(uid), "%s", "");
-			}
-			generate_msgid(uid, 255, account->address);
+			uid = prefs_account_generate_msgid(account);
 			
 			event = vcal_manager_new_event(uid,
 					org, NULL, NULL/*location*/, summary, description, 
 					dtstart, dtend, recur, tzid, url, method, sequence, 
 					ICAL_VTODO_COMPONENT);
+			g_free(uid);
 			
 			/* hack to get default hours */
 			g_free(event->dtstart);
@@ -376,7 +367,7 @@ static void vcalviewer_answer_set_choices(VCalViewer *vcalviewer, VCalEvent *eve
 	
 	vcalviewer_show_unavailable(vcalviewer, FALSE);
 
-	if (method == ICAL_METHOD_REQUEST && event && !event->rec_occurence) {
+	if (method == ICAL_METHOD_REQUEST && event && !event->rec_occurrence) {
 		PrefsAccount *account = vcal_manager_get_account_from_event(event);
 		
 		if (!account)
@@ -567,7 +558,7 @@ void vcalviewer_display_event (VCalViewer *vcalviewer, VCalEvent *event)
 			GTK_LABEL_SET_TEXT_TRIMMED(GTK_LABEL(vcalviewer->start), tmp);
 			gtk_label_set_use_markup(GTK_LABEL(vcalviewer->start), TRUE);
 			g_free(tmp);
-		} else if (event->rec_occurence) {
+		} else if (event->rec_occurrence) {
 			gchar *tmp = g_strdup_printf(g_strconcat("%s <span weight=\"bold\">",
 							_("(this event is part of a recurring event)"),
 							"</span>", NULL),
