@@ -421,7 +421,7 @@ static void prefs_filtering_create(void)
                     	  (GtkAttachOptions) (GTK_FILL|GTK_EXPAND),
                     	  (GtkAttachOptions) (0), 0, 0);
 
-	cond_btn =  gtk_button_new_with_mnemonic (_(" D_efine... "));
+	cond_btn =  gtk_button_new_with_mnemonic (_(" Def_ine... "));
 	gtk_widget_show (cond_btn);
   	gtk_table_attach (GTK_TABLE (table), cond_btn, 2, 3, 2, 3,
                     	  (GtkAttachOptions) (GTK_FILL),
@@ -483,7 +483,7 @@ static void prefs_filtering_create(void)
 	CLAWS_SET_TIP(subst_btn,
 			_("Replace the selected rule in list with the rule above"));
 
-	del_btn = gtk_button_new_with_mnemonic (_("Re_move"));
+	del_btn = gtk_button_new_with_mnemonic (_("D_elete"));
 	gtk_button_set_image(GTK_BUTTON(del_btn),
 			gtk_image_new_from_stock(GTK_STOCK_REMOVE,GTK_ICON_SIZE_BUTTON));
 	gtk_box_pack_start (GTK_BOX (btn_hbox), del_btn, FALSE, TRUE, 0);
