@@ -40,7 +40,7 @@
 #include "prefs_common.h"
 #include "utils.h"
 #include "gtkutils.h"
-#include "passcrypt.h"
+#include "password.h"
 #include "codeconv.h"
 
 #define CL(x)	(((gulong) (x) >> (gulong) 8) & 0xFFUL)
@@ -169,6 +169,7 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 
 		switch (param[i].type) {
 		case P_STRING:
+		case P_PASSWORD:
 		{
 			gchar *tmp = NULL;
 
@@ -216,23 +217,6 @@ static void prefs_config_parse_one_line(PrefParam *param, const gchar *buf)
 				/* be compatible and accept ints */
 				*((gulong *)param[i].data) = strtoul(value, 0, 10); 
 			break;
-		case P_PASSWORD:
-			g_free(*((gchar **)param[i].data));
-			if (value[0] == '!') {
-				gchar *tmp;
-				gsize len;
-
-				tmp = g_base64_decode(&value[1], &len);
-				passcrypt_decrypt(tmp, len);
-
-				*((gchar **)param[i].data) =
-					*tmp ? g_strdup(tmp) : NULL;
-				g_free(tmp);
-			} else {
-				*((gchar **)param[i].data) =
-					*value ? g_strdup(value) : NULL;
-			}
-			break;
 		default:
 			break;
 		}
@@ -335,7 +319,7 @@ void prefs_write_config(PrefParam *param, const gchar *label,
 gint prefs_write_param(PrefParam *param, FILE *fp)
 {
 	gint i;
-	gchar buf[PREFSBUFSIZE];
+	gchar buf[PREFSBUFSIZE] = "";
 
 	for (i = 0; param[i].name != NULL; i++) {
 		switch (param[i].type) {
@@ -361,6 +345,9 @@ gint prefs_write_param(PrefParam *param, FILE *fp)
 			g_free(tmp);
 			break;
 		}
+		case P_PASSWORD:
+			buf[0] = '\0'; /* Passwords are written to password store. */
+			break;
 		case P_INT:
 			g_snprintf(buf, sizeof(buf), "%s=%d\n", param[i].name,
 				   *((gint *)param[i].data));
@@ -381,27 +368,6 @@ gint prefs_write_param(PrefParam *param, FILE *fp)
 			g_snprintf(buf, sizeof buf,  "%s=#%6.6lx\n", param[i].name,
 				   *((gulong *) param[i].data));
 			break;
-		case P_PASSWORD:
-			{
-				gchar *tmp = NULL, *tmp2 = NULL;
-
-				tmp = *((gchar **)param[i].data);
-				if (tmp) {
-					gint len;
-
-					tmp = g_strdup(tmp);
-					len = strlen(tmp);
-					passcrypt_encrypt(tmp, len);
-					tmp2 = g_base64_encode(tmp, len);
-					g_free(tmp);
-					tmp = tmp2;
-				}
-				g_snprintf(buf, sizeof(buf), "%s=!%s\n", param[i].name,
-					   tmp ?
-					   tmp : "");
-				g_free(tmp);
-			}
-			break;
 		default:
 			/* unrecognized, fail */
 			debug_print("Unrecognized parameter type\n");
@@ -662,11 +628,12 @@ void prefs_set_data_from_entry(PrefParam *pparam)
 
 	switch (pparam->type) {
 	case P_STRING:
-	case P_PASSWORD:
 		str = (gchar **)pparam->data;
 		g_free(*str);
 		*str = entry_str[0] ? g_strdup(entry_str) : NULL;
 		break;
+	case P_PASSWORD:
+		break;
 	case P_USHORT:
 		*((gushort *)pparam->data) = atoi(entry_str);
 		break;
@@ -700,12 +667,10 @@ void prefs_set_escaped_data_from_entry(PrefParam *pparam)
 void prefs_set_entry(PrefParam *pparam)
 {
 	gchar **str;
-
 	cm_return_if_fail(*pparam->widget != NULL);
 
 	switch (pparam->type) {
 	case P_STRING:
-	case P_PASSWORD:
 		str = (gchar **)pparam->data;
 		gtk_entry_set_text(GTK_ENTRY(*pparam->widget),
 				   *str ? *str : "");
@@ -752,7 +717,6 @@ void prefs_set_data_from_text(PrefParam *pparam)
 
 	switch (pparam->type) {
 	case P_STRING:
-	case P_PASSWORD:
 		str = (gchar **)pparam->data;
 		g_free(*str);
 		if (GTK_IS_EDITABLE(*pparam->widget)) {   /* need? */
@@ -825,7 +789,6 @@ void prefs_set_text(PrefParam *pparam)
 
 	switch (pparam->type) {
 	case P_STRING:
-	case P_PASSWORD:
 		str = (gchar **)pparam->data;
 		if (*str) {
 			bufp = buf = alloca(strlen(*str) + 1);
