@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 #include "defs.h"
@@ -85,12 +84,13 @@
 #include "pixmaps/queue_close_hrm.xpm"
 #include "pixmaps/queue_open.xpm"
 #include "pixmaps/queue_open_hrm.xpm"
-#include "pixmaps/claws-mail_icon.xpm"
-#include "pixmaps/claws-mail_compose_logo.xpm"
+#include "pixmaps/claws_mail_icon.xpm"
+#include "pixmaps/claws_mail_icon_64.xpm"
+#include "pixmaps/claws_mail_compose_logo.xpm"
 #ifndef GENERIC_UMPC
-#include "pixmaps/claws-mail_logo.xpm"
+#include "pixmaps/claws_mail_logo.xpm"
 #else
-#include "pixmaps/claws-mail_logo-small.xpm"
+#include "pixmaps/claws_mail_logo_small.xpm"
 #endif
 #include "pixmaps/address_book.xpm"
 #include "pixmaps/unread.xpm"
@@ -146,11 +146,13 @@
 #include "pixmaps/outbox_open_hrm.xpm"
 #include "pixmaps/outbox_close.xpm"
 #include "pixmaps/outbox_close_hrm.xpm"
-#include "pixmaps/trash.xpm"
+#include "pixmaps/trash_open.xpm"
+#include "pixmaps/trash_close.xpm"
 #include "pixmaps/delete_btn.xpm"
 #include "pixmaps/cancel.xpm"
 #include "pixmaps/trash_btn.xpm"
-#include "pixmaps/trash_hrm.xpm"
+#include "pixmaps/trash_open_hrm.xpm"
+#include "pixmaps/trash_close_hrm.xpm"
 #include "pixmaps/drafts_close.xpm"
 #include "pixmaps/drafts_open.xpm"
 #include "pixmaps/dir_close_mark.xpm"
@@ -165,15 +167,22 @@
 #include "pixmaps/outbox_open_hrm_mark.xpm"
 #include "pixmaps/outbox_close_mark.xpm"
 #include "pixmaps/outbox_close_hrm_mark.xpm"
-#include "pixmaps/trash_mark.xpm"
+#include "pixmaps/trash_open_mark.xpm"
+#include "pixmaps/trash_close_mark.xpm"
 #include "pixmaps/queue_close_mark.xpm"
 #include "pixmaps/queue_close_hrm_mark.xpm"
 #include "pixmaps/queue_open_mark.xpm"
 #include "pixmaps/queue_open_hrm_mark.xpm"
-#include "pixmaps/trash_hrm_mark.xpm"
+#include "pixmaps/trash_open_hrm_mark.xpm"
+#include "pixmaps/trash_close_hrm_mark.xpm"
 #include "pixmaps/drafts_close_mark.xpm"
 #include "pixmaps/drafts_open_mark.xpm"
-#include "pixmaps/dir_noselect.xpm"
+#include "pixmaps/dir_noselect_close.xpm"
+#include "pixmaps/dir_noselect_close_mark.xpm"
+#include "pixmaps/dir_noselect_open.xpm"
+#include "pixmaps/dir_subs_close_mark.xpm"
+#include "pixmaps/dir_subs_close.xpm"
+#include "pixmaps/dir_subs_open.xpm"
 #include "pixmaps/spam.xpm"
 #include "pixmaps/spam_btn.xpm"
 #include "pixmaps/ham_btn.xpm"
@@ -182,16 +191,29 @@
 #include "pixmaps/selection.xpm"
 #include "pixmaps/watchthread.xpm"
 #include "pixmaps/empty.xpm"
-#include "pixmaps/tray_newmail.offline.xpm"
+#include "pixmaps/tray_newmail_offline.xpm"
 #include "pixmaps/tray_newmail.xpm"
-#include "pixmaps/tray_newmarkedmail.offline.xpm"
+#include "pixmaps/tray_newmarkedmail_offline.xpm"
 #include "pixmaps/tray_newmarkedmail.xpm"
-#include "pixmaps/tray_nomail.offline.xpm"
+#include "pixmaps/tray_nomail_offline.xpm"
 #include "pixmaps/tray_nomail.xpm"
-#include "pixmaps/tray_unreadmail.offline.xpm"
+#include "pixmaps/tray_unreadmail_offline.xpm"
 #include "pixmaps/tray_unreadmail.xpm"
-#include "pixmaps/tray_unreadmarkedmail.offline.xpm"
+#include "pixmaps/tray_unreadmarkedmail_offline.xpm"
 #include "pixmaps/tray_unreadmarkedmail.xpm"
+#include "pixmaps/doc_index.xpm"
+#include "pixmaps/doc_index_close.xpm"
+#include "pixmaps/doc_info.xpm"
+#include "pixmaps/first_arrow.xpm"
+#include "pixmaps/last_arrow.xpm"
+#include "pixmaps/left_arrow.xpm"
+#include "pixmaps/right_arrow.xpm"
+#include "pixmaps/rotate_left.xpm"
+#include "pixmaps/rotate_right.xpm"
+#include "pixmaps/zoom_fit.xpm"
+#include "pixmaps/zoom_in.xpm"
+#include "pixmaps/zoom_out.xpm"
+#include "pixmaps/zoom_width.xpm"
 
 typedef struct _StockPixmapData	StockPixmapData;
 
@@ -315,18 +337,18 @@ static StockPixmapData pixmaps[] =
 	{queue_close_hrm_xpm			, NULL, NULL, "queue_close_hrm", NULL},
 	{queue_open_xpm				, NULL, NULL, "queue_open", NULL},
 	{queue_open_hrm_xpm			, NULL, NULL, "queue_open_hrm", NULL},
-	{trash_xpm				, NULL, NULL, "trash_open", NULL},
-	{trash_hrm_xpm				, NULL, NULL, "trash_open_hrm", NULL},
-	{trash_xpm				, NULL, NULL, "trash_close", NULL},
-	{trash_hrm_xpm				, NULL, NULL, "trash_close_hrm", NULL},
+	{trash_open_xpm				, NULL, NULL, "trash_open", NULL},
+	{trash_open_hrm_xpm			, NULL, NULL, "trash_open_hrm", NULL},
+	{trash_close_xpm			, NULL, NULL, "trash_close", NULL},
+	{trash_close_hrm_xpm			, NULL, NULL, "trash_close_hrm", NULL},
 	{queue_close_mark_xpm			, NULL, NULL, "queue_close_mark", NULL},
 	{queue_close_hrm_mark_xpm		, NULL, NULL, "queue_close_hrm_mark", NULL},
 	{queue_open_mark_xpm			, NULL, NULL, "queue_open_mark", NULL},
 	{queue_open_hrm_mark_xpm		, NULL, NULL, "queue_open_hrm_mark", NULL},
-	{trash_mark_xpm				, NULL, NULL, "trash_open_mark", NULL},
-	{trash_hrm_mark_xpm			, NULL, NULL, "trash_open_hrm_mark", NULL},
-	{trash_mark_xpm				, NULL, NULL, "trash_close_mark", NULL},
-	{trash_hrm_mark_xpm			, NULL, NULL, "trash_close_hrm_mark", NULL},
+	{trash_open_mark_xpm			, NULL, NULL, "trash_open_mark", NULL},
+	{trash_open_hrm_mark_xpm		, NULL, NULL, "trash_open_hrm_mark", NULL},
+	{trash_close_mark_xpm			, NULL, NULL, "trash_close_mark", NULL},
+	{trash_close_hrm_mark_xpm		, NULL, NULL, "trash_close_hrm_mark", NULL},
 	{unread_xpm				, NULL, NULL, "unread", NULL},
 	{vcard_xpm				, NULL, NULL, "vcard", NULL},
 	{online_xpm				, NULL, NULL, "online", NULL},
@@ -367,6 +389,7 @@ static StockPixmapData pixmaps[] =
 	{privacy_emblem_warn_xpm		, NULL, NULL, "privacy_emblem_warn", NULL},
 	{mime_message_xpm			, NULL, NULL, "mime_message", NULL},
 	{claws_mail_icon_xpm			, NULL, NULL, "claws_mail_icon", NULL},
+	{claws_mail_icon_64_xpm			, NULL, NULL, "claws_mail_icon_64", NULL},
 	{read_xpm				, NULL, NULL, "read", NULL},
 	{delete_btn_xpm				, NULL, NULL, "delete_btn", NULL},
 	{cancel_xpm				, NULL, NULL, "cancel", NULL},
@@ -377,7 +400,12 @@ static StockPixmapData pixmaps[] =
 #else
 	{claws_mail_logo_small_xpm		, NULL, NULL, "claws_mail_logo_small", NULL},
 #endif
-        {dir_noselect_xpm                       , NULL, NULL, "dir_noselect" , NULL},
+        {dir_noselect_close_xpm                 , NULL, NULL, "dir_noselect_close" , NULL},
+        {dir_noselect_close_mark_xpm            , NULL, NULL, "dir_noselect_close_mark" , NULL},
+        {dir_noselect_open_xpm                  , NULL, NULL, "dir_noselect_open" , NULL},
+        {dir_subs_close_mark_xpm                , NULL, NULL, "dir_subs_close_mark" , NULL},
+        {dir_subs_close_xpm                     , NULL, NULL, "dir_subs_close" , NULL},
+        {dir_subs_open_xpm                      , NULL, NULL, "dir_subs_open" , NULL},
         {spam_xpm                               , NULL, NULL, "spam" , NULL},
         {spam_btn_xpm                           , NULL, NULL, "spam_btn" , NULL},
         {ham_btn_xpm                            , NULL, NULL, "ham_btn" , NULL},
@@ -385,16 +413,29 @@ static StockPixmapData pixmaps[] =
 	{copied_xpm				, NULL, NULL, "copied", NULL},
 	{selection_xpm				, NULL, NULL, "selection", NULL},
 	{watchthread_xpm			, NULL, NULL, "watchthread", NULL},
-	{tray_newmail_offline_xpm		, NULL, NULL, "tray_newmail.offline", NULL},
+	{tray_newmail_offline_xpm		, NULL, NULL, "tray_newmail_offline", NULL},
 	{tray_newmail_xpm			, NULL, NULL, "tray_newmail", NULL},
-	{tray_newmarkedmail_offline_xpm		, NULL, NULL, "tray_newmarkedmail.offline", NULL},
+	{tray_newmarkedmail_offline_xpm		, NULL, NULL, "tray_newmarkedmail_offline", NULL},
 	{tray_newmarkedmail_xpm			, NULL, NULL, "tray_newmarkedmail", NULL},
-	{tray_nomail_offline_xpm		, NULL, NULL, "tray_nomail.offline", NULL},
+	{tray_nomail_offline_xpm		, NULL, NULL, "tray_nomail_offline", NULL},
 	{tray_nomail_xpm			, NULL, NULL, "tray_nomail", NULL},
-	{tray_unreadmail_offline_xpm		, NULL, NULL, "tray_unreadmail.offline", NULL},
+	{tray_unreadmail_offline_xpm		, NULL, NULL, "tray_unreadmail_offline", NULL},
 	{tray_unreadmail_xpm			, NULL, NULL, "tray_unreadmail", NULL},
-	{tray_unreadmarkedmail_offline_xpm	, NULL, NULL, "tray_unreadmarkedmail.offline", NULL},
+	{tray_unreadmarkedmail_offline_xpm	, NULL, NULL, "tray_unreadmarkedmail_offline", NULL},
 	{tray_unreadmarkedmail_xpm		, NULL, NULL, "tray_unreadmarkedmail", NULL},
+	{doc_index_xpm				, NULL, NULL, "doc_index", NULL},
+	{doc_index_close_xpm			, NULL, NULL, "doc_index_close", NULL},
+	{doc_info_xpm				, NULL, NULL, "doc_info", NULL},
+	{first_arrow_xpm			, NULL, NULL, "first_arrow", NULL},
+	{last_arrow_xpm				, NULL, NULL, "last_arrow", NULL},
+	{left_arrow_xpm				, NULL, NULL, "left_arrow", NULL},
+	{right_arrow_xpm			, NULL, NULL, "right_arrow", NULL},
+	{rotate_left_xpm			, NULL, NULL, "rotate_left", NULL},
+	{rotate_right_xpm			, NULL, NULL, "rotate_right", NULL},
+	{zoom_fit_xpm				, NULL, NULL, "zoom_fit", NULL},
+	{zoom_in_xpm				, NULL, NULL, "zoom_in", NULL},
+	{zoom_out_xpm				, NULL, NULL, "zoom_out", NULL},
+	{zoom_width_xpm				, NULL, NULL, "zoom_width", NULL},
         {empty_xpm                              , NULL, NULL, "empty" , NULL}
 };
 
