@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2015 Colin Leroy <colin@colino.net>
+ * Copyright (C) 1999-2016 Colin Leroy <colin@colino.net>
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -271,27 +271,27 @@ static gchar *accountrc_tmpl =
 	"#default is \"Mail\"\n"
 	"#mailbox=\n"
 	"\n"
-	"#whether to use ssl on smtp connections\n"
-	"#default is 0, 1 is ssl, 2 is starttls\n"
+	"#whether to use encryption on SMTP connections\n"
+	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
 	"#smtpssl=\n"
 	"\n"
-	"#whether to use ssl on pop or imap connections\n"
-	"#default is 0, 1 is ssl, 2 is starttls\n"
+	"#whether to use encryption on POP3 or IMAP connections\n"
+	"#default is 0, 1 is SSL/TLS, 2 is STARTTLS\n"
 	"#recvssl=\n"
 	"\n"
-	"#SSL client certificate path for SMTP\n"
+	"#SSL/TLS client certificate path for SMTP\n"
 	"#default is empty (no certificate)\n"
 	"#smtpssl_cert=\n"
 	"\n"
-	"#SSL client certificate path for POP/IMAP\n"
+	"#SSL/TLS client certificate path for POP/IMAP\n"
 	"#default is empty (no certificate)\n"
 	"#recvssl_cert=\n"
 	"\n"
-	"#SSL client certificate password for SMTP\n"
+	"#SSL/TLS client certificate password for SMTP\n"
 	"#default is empty (no password)\n"
 	"#smtpssl_cert_pass=\n"
 	"\n"
-	"#SSL client certificate password for POP/IMAP\n"
+	"#SSL/TLS client certificate password for POP/IMAP\n"
 	"#default is empty (no password)\n"
 	"#recvssl_cert_pass=\n"
 	;
@@ -576,9 +576,8 @@ static void write_welcome_email(WizardWindow *wizard)
 		"-------\n"
 		"Claws Mail is free software, released under the terms\n"
 		"of the GNU General Public License, version 3 or later, as\n"
-		"published by the Free Software Foundation, 51 Franklin Street,\n"
-		"Fifth Floor, Boston, MA 02110-1301, USA. The license can be\n"
-		"found at <%s>.\n"
+		"published by the Free Software Foundation. The license can\n"
+		"be found at <%s>.\n"
 		"\n"
 		"DONATIONS\n"
 		"---------\n"
@@ -1163,7 +1162,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->smtp_use_ssl = gtk_check_button_new_with_label(
-					_("Use SSL to connect to SMTP server"));
+					_("Use SSL/TLS to connect to SMTP server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->smtp_use_ssl),
 			tmpl.smtpssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->smtp_use_ssl, FALSE, FALSE, 0);
@@ -1174,7 +1173,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	wizard->smtp_use_tls = gtk_check_button_new_with_label(
-					_("Use SSL via STARTTLS"));
+					_("Use STARTTLS command to start encryption"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->smtp_use_tls),
 			tmpl.smtpssl == 2);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->smtp_use_tls, FALSE, FALSE, 0);
@@ -1186,7 +1185,7 @@ static GtkWidget* smtp_page (WizardWindow * wizard)
 	hbox_spc = gtk_hbox_new (FALSE, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client SSL certificate (optional)"));
+	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 	gtk_table_attach(GTK_TABLE(smtp_cert_table), hbox, 0, 3, 0, 1, GTK_FILL, 0, 0, 0);
@@ -1583,7 +1582,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	hbox = gtk_hbox_new(FALSE, VSPACING_NARROW);
 	gtk_box_pack_start (GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 	wizard->recv_use_ssl = gtk_check_button_new_with_label(
-					_("Use SSL to connect to receiving server"));
+					_("Use SSL/TLS to connect to receiving server"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->recv_use_ssl),
 			tmpl.recvssl != 0);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_use_ssl, FALSE, FALSE, 0);
@@ -1594,7 +1593,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);	
 	wizard->recv_use_tls = gtk_check_button_new_with_label(
-					_("Use SSL via STARTTLS"));
+					_("Use STARTTLS command to start encryption"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wizard->recv_use_tls),
 			tmpl.recvssl == 2);
 	gtk_box_pack_start(GTK_BOX(hbox), wizard->recv_use_tls, FALSE, FALSE, 0);
@@ -1606,7 +1605,7 @@ static GtkWidget* recv_page (WizardWindow * wizard)
 	hbox_spc = gtk_hbox_new (FALSE, 0);
 	gtk_widget_set_size_request (hbox_spc, 12, -1);
 	gtk_box_pack_start (GTK_BOX (hbox), hbox_spc, FALSE, FALSE, 0);
-	label = gtk_label_new(_("Client SSL certificate (optional)"));
+	label = gtk_label_new(_("Client SSL/TLS certificate (optional)"));
 	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);
 	gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);	
 	gtk_table_attach(GTK_TABLE(recv_cert_table), hbox, 0, 3, 0, 1, GTK_FILL, 0, 0, 0);
